#
# File:		AceMessagePacket.py
#
# Copyright (C)	Thomas Sean Powell & Siegfried Schloissnig
#
#  -------------------------------------------------------------------
#  Ace-python is free software; you can redistribute it and/or
#  modify it under the terms of the GNU General Public License
#  as published by the Free Software Foundation; either version 2
#  of the License, or (at your option) any later version.
#  
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#  
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#  or see the on-line version at http://www.gnu.org/copyleft/gpl.txt
#  -------------------------------------------------------------------
#
# Author:	Siegfried Schloissnig
#
# Description:	Wrapper class for the messages used to
#		talk with the socket server 
#
# Changes:	...
#
# Todo:		...
#

import struct

### supported message types

ACESERV_MSGREQ          =       "ACESERV_MSGREQ"
ACESERV_MSGDATA         =       "ACESERV_MSGDATA"
ACESERV_MSGENCORE       =       "ACESERV_MSGENCORE"
ACESERV_MSGOK           =       "ACESERV_MSGOK"
ACESERV_MSGFAIL         =       "ACESERV_MSGFAIL"
ACESERV_MSGKILL         =       "ACESERV_MSGKILL"

### this is the value for the first field in a message packet
### used to detect which byte-ordering is used

MAGIC			=	0x12345678

### the class

class AceMessagePacket:
	### constructor
	def __init__(self, msgType, msgBody, clientID, maxBytes):
		self.msgType = msgType		# type of the message
		self.msgBody = msgBody		# the message
		self.clientID = clientID	# client ID
		self.maxBytes = maxBytes	# max. bytes we will receive  

	### pack the message fields together
	def getData(self):
                msg = struct.pack("iiiii30s",
			    MAGIC,
                            len(self.msgBody) + 1,
                            1,
                            self.clientID,
                            self.maxBytes,
			    self.msgType)
		# and the message itself 
		msg = msg + self.msgBody + "\0"

                return msg

	### get/set functions for the fields
	def getMaxBytes(self):
		return self.maxBytes

	def getClientID(self):
		return self.clientID

	def getBody(self):
		return self.msgBody

	def getType(self):
		return self.msgType

	### detect the message type
	def isMsgReq(self):
		return self.getType() == ACESERV_MSGREQ

	def isMsgKill(self):
		return self.getType() == ACESERV_MSGKILL

	def isMsgData(self):
		return self.getType() == ACESERV_MSGDATA

	def isMsgOK(self):
		return self.getType() == ACESERV_MSGOK

	def isMsgFail(self):
		return self.getType() == ACESERV_MSGFAIL

	def isMsgEncore(self):
		return self.getType() == ACESERV_MSGENCORE

### create a new AceMessagePacket
def create(msgType, msgBody, clientID = 0, maxBytes = 256):
	return AceMessagePacket(msgType.split("\0")[0],	
				msgBody, 
				clientID, 
				maxBytes) 
	

